==> kpeggy-0.2.tar.gz: kpeggy-0.2/kpeggy/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : jue nov  8 22:42:52 CET 2001
    copyright            : (C) 2001 by Jos?Pablo Fern?dez
    email                : jpablo@localhost.localdomain
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qstring.h>
#include <kapp.h>
#include <klineedit.h>
#include <klocale.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>

#include <iostream.h>
#include <stdlib.h>

#include "kpeggy.h"

#include "astar.h"
#include "midata.h"
#include "matrix.h"
#include "milist.h"



static const char *description =
	I18N_NOOP("Peggy solitarie") ;

int main (int argc, char *argv[])
{

	KAboutData aboutData(
		"kpeggy",	I18N_NOOP("KPeggy"), VERSION,
		description, KAboutData::License_GPL,
		"(c) 2001, Jose Pablo Fernandez",
		0, "", "jpablo@di.uc3m.es" ) ;
	aboutData.addAuthor("Jose Pablo Fernandez", 0, "jpablo@di.uc3m.es");


KCmdLineArgs::init(argc, argv, &aboutData) ;


KApplication app ;


if (app.isRestored())
	RESTORE(KPeggy)
else {
	KPeggy *kpeggy = new KPeggy() ;
	kpeggy->show() ;
}


return app.exec() ;

	
} /* main */

==> kpeggy-0.3.tar.gz: kpeggy-0.3/kpeggy/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : jue nov  8 22:42:52 CET 2001
    copyright            : (C) 2001 by Jos Pablo Fernndez
    email                : jpablo@di.uc3m.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kapp.h>
#include <klocale.h>
#include <kaboutdata.h>
#include <kcmdlineargs.h>

#include "kpeggy.h"

static const char *description =
	I18N_NOOP("Peggy solitarie") ;

int main (int argc, char *argv[])
{

	KAboutData aboutData(
		"kpeggy",	I18N_NOOP("KPeggy"), VERSION,
		description, KAboutData::License_GPL,
		"(c) 2001, Jos Pablo Fernndez",
		0, "", "jpablo@di.uc3m.es" ) ;
	aboutData.addAuthor("Jose Pablo Fernandez", 0, "jpablo@di.uc3m.es");


KCmdLineArgs::init(argc, argv, &aboutData) ;


KApplication app ;


if (app.isRestored())
	RESTORE(KPeggy)
else {
	KPeggy *kpeggy = new KPeggy() ;
	kpeggy->show() ;
}


return app.exec() ;

	
} /* main */
